package com.zh.project0512.controller.manage;


import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.zh.project0512.annotation.adminTokenValid;
import com.zh.project0512.model.Admin;
import com.zh.project0512.model.User;
import com.zh.project0512.service.IAdminService;
import com.zh.project0512.service.IUserService;
import com.zh.project0512.utils.*;
import com.zh.project0512.utils.result.HttpStatusEnum;
import com.zh.project0512.utils.result.Result;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.Data;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;
import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.Map;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author zh
 * @since 2022-05-18
 */
@Tag(name = "后台账号管理")
@RestController
@RequestMapping("manage/admin")
public class AdminController {

    @Autowired
    private IAdminService adminService;

    @Data
    static class LoginParam {
        @NotNull(message = "name不能为空")
        @Schema(title = "账号名称")
        private String name;
        @NotNull(message = "密码不能为空")
        @Schema(title = "密码")
        private String password;
    }

    @Operation(summary = "登录")
    @PostMapping("/login")
    public Result login(@Validated @RequestBody LoginParam param) {
        String name = param.getName();
        String password = param.getPassword();
        QueryWrapper<Admin> qw = new QueryWrapper<>();
        qw.eq("name", name);
        Admin admin = adminService.getOne(qw);
        if (null == admin) {
            return Result.fail(HttpStatusEnum.USER_NOT_EXIST, "未注册！");
        }
        if (!password.equals(admin.getPassword())) {
            return Result.fail(HttpStatusEnum.USER_NOT_EXIST, "密码错误！");
        }
        String token = new JwtUtil().createAdminJWT(admin.getId().toString());
        admin.setToken(token).setLastLoginAt(LocalDateTime.now());
        UpdateWrapper<Admin> uw = new UpdateWrapper<>();
        uw.eq("id", admin.getId()).set("token", token).set("lastLoginAt", LocalDateTime.now());
        adminService.update(uw);
        return Result.success(admin);
    }

    @Data
    static class registerParam {
        @NotNull(message = "name不能为空")
        @Schema(title = "账号名称")
        private String name;
        @NotNull(message = "密码不能为空")
        @Schema(title = "密码")
        @NotNull(message = "密码不能为空")
        private String tel;
        @Schema(title = "密码")
        private String password;
        @Schema(title = "真实名称")
        private String realName;
    }

    @Operation(summary = "注册")
    @PostMapping("register")
    @adminTokenValid
    public Result register(@Validated @RequestBody registerParam param) {
        QueryWrapper<Admin> qw = new QueryWrapper<>();
        qw.eq("name", param.getName());
        if (null != adminService.getOne(qw)) {
            return Result.fail(HttpStatusEnum.CUSTOM_EXCEPTION, "已注册！");
        }
        Admin admin = new Admin().setName(param.getName()).setPassword(param.getPassword()).setTel(param.getTel()).setRealName(param.getRealName()).setCreatAt(LocalDateTime.now());
        adminService.save(admin);
        return Result.success(admin);
    }

}
