package com.zh.project0512.controller.wxApp;

import com.zh.project0512.model.dto.OperationRoleJurisdictionDTO;
import com.zh.project0512.model.dto.UserRoleInsertDTO;
import com.zh.project0512.model.dto.UserRoleListDTO;
import com.zh.project0512.model.dto.UserRoleUpdateDTO;
import com.zh.project0512.model.vo.UserRoleListVo;
import com.zh.project0512.service.IUserRoleService;
import com.zh.project0512.utils.result.Result;
import com.zh.project0512.utils.result.ResultPageInfo;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * 用户角色
 */
@Tag(name = "用户角色")
@RestController
@RequestMapping("/wxApp/userRole")
public class UserRoleController {
    @Resource
    IUserRoleService userRoleService;


    /**
     * 查询用户角色
     * @param userRoleListDTO 用户角色 list DTO
     * @return 用户角色
     */
    @PostMapping("/list")
    public ResultPageInfo<UserRoleListVo> list(@Validated @RequestBody UserRoleListDTO userRoleListDTO){
        return ResultPageInfo.success(userRoleService.list(userRoleListDTO));
    }

    /**
     * 添加用户角色
     * @param userRoleInsertDTO 用户角色添加
     * @return 操作信息
     */
    @PostMapping("/insert")
    public Result<String> insert(@Validated @RequestBody UserRoleInsertDTO userRoleInsertDTO){
        if (userRoleService.insert(userRoleInsertDTO)){
            return Result.success("添加用户角色","操作成功");
        }else {
            throw new RuntimeException("添加失败");
        }
    }

    /**
     * 修改用户角色
     * @param userRoleUpdateDTO 用户角色 update DTO
     * @return 操作信息
     */
    @PostMapping("/update")
    public Result<String> update(@Validated @RequestBody UserRoleUpdateDTO userRoleUpdateDTO){
        if (userRoleService.update(userRoleUpdateDTO)){
            return Result.success("修改用户角色","操作成功");
        }else {
            throw new RuntimeException("修改失败");
        }
    }



}
