package com.zh.project0512.serviceImpl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.zh.project0512.mapper.UserRoleMapper;
import com.zh.project0512.model.UserPointsRecords;
import com.zh.project0512.model.UserRole;
import com.zh.project0512.model.dto.UserRoleInsertDTO;
import com.zh.project0512.model.dto.UserRoleListDTO;
import com.zh.project0512.model.dto.UserRoleUpdateDTO;
import com.zh.project0512.model.vo.UserPointsRecordListVo;
import com.zh.project0512.model.vo.UserRoleListVo;
import com.zh.project0512.service.IUserRoleService;
import com.zh.project0512.utils.PropertyUtils;
import com.zh.project0512.utils.page.PageInfo;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.UUID;

@Service
public class UserRoleServiceImpl implements IUserRoleService {
    @Resource
    UserRoleMapper userRoleMapper;

    @Override
    public PageInfo<UserRoleListVo> list(UserRoleListDTO userRoleListDTO) {
        ArrayList<UserRoleListVo> userRoleListVoList = new ArrayList<>();
        QueryWrapper<UserRole> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(StringUtils.isNotBlank(userRoleListDTO.getName()),"name",userRoleListDTO.getName());

        Page<UserRole> page = new Page<>(userRoleListDTO.getPageNum(), userRoleListDTO.getPageSize());
        IPage<UserRole> userRoleIPage = userRoleMapper.selectPage(page, queryWrapper);
        List<UserRole> records = userRoleIPage.getRecords();
        if (records != null && records.size()>0){
            for (UserRole record : records) {
                UserRoleListVo userRoleListVo = new UserRoleListVo();
                PropertyUtils.copyProperties(record,userRoleListVo);
                userRoleListVoList.add(userRoleListVo);
            }
        }
        return new PageInfo<>(userRoleIPage.getPages(), userRoleListVoList, userRoleIPage.getTotal());
    }

    @Override
    public boolean insert(UserRoleInsertDTO userRoleInsertDTO) {
        UserRole userRole = new UserRole();
        userRole.setName(userRoleInsertDTO.getName());
        userRole.setCode(UUID.randomUUID().toString().replace("-",""));
        userRole.setCreateAt(new Date());
        int insert = userRoleMapper.insert(userRole);
        return insert > 0;
    }

    @Override
    public boolean update(UserRoleUpdateDTO userRoleUpdateDTO) {
        UserRole userRole = userRoleMapper.selectById(userRoleUpdateDTO.getId());
        if (userRole == null){
            throw new RuntimeException("记录不存在");
        }

        userRole.setName(userRoleUpdateDTO.getName());
        int update = userRoleMapper.updateById(userRole);
        return update > 0;
    }
}
